# Pigreads

[![Pipeline Status][pipeline-badge]][pipeline-link]
[![Coverage Report][coverage-badge]][coverage-link]
[![Latest Release][release-badge]][release-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

<!-- SPHINX-START -->

Pigreads stands for **Python-integrated GPU-enabled reaction diffusion solver**.

<!-- prettier-ignore-start -->
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/pigreads
[conda-link]:               https://github.com/conda-forge/pigreads-feedstock
[coverage-badge]:           https://gitlab.com/pigreads/pigreads/badges/main/coverage.svg
[coverage-link]:            https://gitlab.com/pigreads/pigreads/-/commits/main
[pipeline-badge]:           https://gitlab.com/pigreads/pigreads/badges/main/pipeline.svg
[pipeline-link]:            https://gitlab.com/pigreads/pigreads/-/pipelines
[pypi-link]:                https://pypi.org/project/pigreads/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/pigreads
[pypi-version]:             https://img.shields.io/pypi/v/pigreads
[release-badge]:            https://gitlab.com/pigreads/pigreads/-/badges/release.svg
[release-link]:             https://gitlab.com/pigreads/pigreads/-/releases
[rtd-badge]:                https://readthedocs.org/projects/pigreads/badge/?version=latest
[rtd-link]:                 https://pigreads.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->
